#
# spec file for package rook
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rook
Version:        1.2.7+git0.g1acfd182
Release:        lp152.1.25
Summary:        Orchestrator for distributed storage systems in cloud-native environments
License:        Apache-2.0
Group:          System/Filesystems
URL:            https://rook.io/

Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-%{version}-vendor.tar.xz
Source98:       README
Source99:       update-tarball.sh

# When possible, a patch is preferred over link-time overrides because the patch will fail if the
# upstream source is updated without the package maintainers knowing. Patches reduce user error when
# creating a new SUSE release branch of Rook.

# Change CSI images to dummy value that needs to be replaced at link time. Use dummy patch so that
# upstream changes will cause build failures if there are updates maintainers miss manually.
Patch0:         csi-dummy-images.patch
# Change CSI template paths to match those installed by rook-k8s-manifests
Patch1:         csi-template-paths.patch
# Change the default FlexVolume dir path to support Kubic.
Patch2:         flexvolume-dir.patch
# Orchestrator CLI renamed from orchestrator -> orch
Patch3:         orchestrator-cli-rename.patch

%if 0%{?suse_version}
# _insert_obs_source_lines_here
ExclusiveArch:  x86_64 aarch64 ppc64 ppc64le
%endif

# Go and spec requirements
BuildRequires:  go
BuildRequires:  golang-packaging
BuildRequires:  xz

# Rook requirements
BuildRequires:  curl
BuildRequires:  git
BuildRequires:  grep

# Ceph version is needed to set correct container tag in manifests
BuildRequires:  ceph
# ceph-csi driver version is needed to update manifest with it
BuildRequires:  ceph-csi

# Rook runtime requirements - referenced from packages installed in Rook images
# From images/ceph/Dockerfile
Requires:       tini
# From Ceph base container: github.com/ceph/ceph-container/src/daemon-base/...
Requires:       pattern() = ceph_base

%description
Rook is a cloud-native storage orchestrator for Kubernetes, providing
the platform, framework, and support for a diverse set of storage
solutions to integrate with cloud-native environments.

See https://github.com/rook/rook for more information.

################################################################################
# Rook FlexVolume driver metadata
################################################################################
%package rookflex
Summary:        Rook FlexVolume driver
Group:          System/Filesystems

%description rookflex
Rook uses FlexVolume to integrate with Kubernetes for performing storage
operations.

################################################################################
# Rook and Ceph manifests metadata
################################################################################
%package k8s-yaml
Summary:        Kubernetes YAML file manifests for deploying a Ceph cluster
Group:          System/Management
BuildArch:      noarch
BuildRequires:  ceph

%description k8s-yaml
This package contains the yaml files required to deploy and run the
Rook-Ceph operator and Ceph clusters in a Kubernetes cluster.

################################################################################
# Rook ceph operator helm charts
################################################################################
%package ceph-helm-charts
Summary:        Rook Ceph operator helm charts
Group:          System/Management
BuildArch:      noarch

%description ceph-helm-charts
Helm helps manage Kubernetes applications. Helm Charts define,
install, and upgrade Kubernetes applications. Rook is a
cloud-native storage orchestrator for Kubernetes, providing
the platform, framework, and support for a diverse set of storage
solutions to integrate with cloud-native environments.

This package contains Helm Charts for Rook.

################################################################################
# Rook integration test binary metadata
################################################################################
%package integration
Summary:        Application which runs Rook integration tests
Group:          System/Benchmark

%description integration
This package is intended to be used only for testing. Please don't install it
in production environments.

Rook's integration tests conveniently get built into a standalone binary. The
tests require a running Kubernetes cluster, and the image being tested must be
pushed to all Kubernetes cluster nodes as 'rook/ceph:master'. They also require
that 'kubectl' works without additional connection arguments from the system
which will run the binary. The integration tests can be flaky and are best run
on a Kubernetes cluster which has not previously run the integration tests.

The list of possible integration test suites can be gotten from the integration
binary with the argument [-test.list '.*']. A subset of test suites can be run
by specifying a regular expression (or a specific test suite name) as an
argument to [-test.run]. All Ceph test suites can be run with the argument
[-test.run 'TestCeph'].

################################################################################
# The tasty, meaty build section
################################################################################
%define _buildshell /bin/bash

%{go_nostrip}
%{go_provides}

%prep
%setup -q -n %{name}
%setup -q -n %{name} -T -D -b 1 # unpack Source1, don't delete what was unpacked before

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

# determine image names to use in manifests depending on the base os type
# 15.2.2.18 is replaced at build time by the _service
%global rook_container_version 1.2.7.0  # this is updated by update-tarball.sh
%if 0%{?is_opensuse}
%global rook_image     registry.opensuse.org/opensuse/rook/ceph:%{rook_container_version}.%{release}
%global ceph_image     registry.opensuse.org/opensuse/ceph/ceph:15.2.2.18
%global ceph_csi_image registry.opensuse.org/opensuse/cephcsi/cephcsi:1.2.2.0
%else # is SES
%if 0%{?sle_version} >= 150200
%global rook_image     registry.suse.com/ses/7/rook/ceph:%{rook_container_version}.%{release}
%global ceph_image     registry.suse.com/ses/7/ceph/ceph:15.2.2.18
%global ceph_csi_image registry.suse.com/ses/7/cephcsi/cephcsi:1.2.2.0
%else
%global rook_image     registry.suse.com/ses/6/rook/ceph:%{rook_container_version}.%{release}
%global ceph_image     registry.suse.com/ses/6/ceph/ceph:15.2.2.18
%global ceph_csi_image registry.suse.com/ses/6/cephcsi/cephcsi:1.2.2.0
%endif
%endif

%build

# we need to remove unsupported by Rook symbols from version
version_parsed=%{version}
version_parsed="${version_parsed//[+]/-}"

linker_flags=(
    # Set Rook version - absolutely required
    "-X" "github.com/rook/rook/pkg/version.Version=$version_parsed"
    # CSI images only known at build time, so use a linker flag instead of patch
    "-X" "github.com/rook/rook/pkg/operator/ceph/csi.DefaultCSIPluginImage=%{ceph_csi_image}"
)
build_flags=("-ldflags" "${linker_flags[*]}")

%goprep github.com/rook/rook
%gobuild "${build_flags[@]}" cmd/rook
%gobuild "${build_flags[@]}" cmd/rookflex

# BUILDING TEST BINARIES, NOTES:
# Building test binaries works differently than main binaries; test binaries are built by 'go test',
#     not 'go build' or 'go install'.
# Spec build tooling provides 'gotest', but it expects to run the tests, which we cannot do with
#     the integration tests at build time, so we run this manually. This may be fragile.
# To compile but not run test binaries, we don't need the build flags needed by main binaries, but
#     we do need: -c (compile test binary) and -o=<output-location> (output file)
# 'goprep' does not set GOTPATH or GOBIN despite what the documentation might say; that is set in
#     'gobuild', so we need to set it for our manual run of 'go test'.
# Because this is a test binary which we SHOULD NOT ship to customers, we shouldn't need to follow
#     every single go build best practice, and we don't need to worry about this becoming too out of
#     date. We can specify some important flags for debugging bad builds:
#         -v (orint package names), -x (print commands)]
#    and flags to get rid of RPMLINT report warnings/errors:
#         -buildmode=pie (position-independent executable)
GOPATH=%{_builddir}/go GOBIN="${GOPATH}"/bin \
    go test -v -x -buildmode=pie -c \
        -o %{_builddir}/go/bin/rook-integration github.com/rook/rook/tests/integration

%install
rook_bin_location=%{_builddir}/go/bin/
install_location=%{buildroot}%{_bindir}

install --mode=755 --directory "${install_location}"

for binary in rook rookflex rook-integration; do
    install --preserve-timestamps --mode=755 \
        --target-directory="${install_location}" \
        "${rook_bin_location}"/"${binary}"
done

# install Rook's toolbox script alongside main binary
install --preserve-timestamps --mode=755 \
    --target-directory="${install_location}" \
    images/ceph/toolbox.sh

# Install provided yaml files to download and run the Rook operator and Ceph containers
mkdir -p %{buildroot}%{_datadir}/k8s-yaml/rook/ceph
cp -pr cluster/examples/kubernetes/ceph/* %{buildroot}%{_datadir}/k8s-yaml/rook/ceph/

################################################################################
# Check that linker flags are applied
################################################################################
rook_bin="$rook_bin_location"rook

# Check Rook version is set
bin_version="$("$rook_bin" version)"
version_parsed=%{version}
version_parsed="${version_parsed//[+]/-}"
if [[ ! "$bin_version" =~ "$version_parsed" ]]; then
    echo "Rook version not set correctly!"
    exit 1
fi

# Check Ceph CSI default image is set
if grep --binary --text dummy-value-that-should-be-replaced-at-link-time "$rook_bin"; then
    echo "Default CSI image was not set!"
    exit 1
fi
if ! grep --binary --text "%{ceph_csi_image}" "$rook_bin"; then
    echo "Default CSI image was set to wrong value!"
    exit 1
fi

################################################################################
# Update manifests with images coming from Build Service
################################################################################
# set rook, ceph and ceph-csi container versions
sed -i -e "s|image: .*|image: %{rook_image}|g" %{buildroot}%{_datadir}/k8s-yaml/rook/ceph/operator*
sed -i -e "s|\".*/cephcsi/cephcsi:.*|\"%{ceph_csi_image}\"|g" %{buildroot}%{_datadir}/k8s-yaml/rook/ceph/operator*
sed -i -e "s|image: .*|image: %{ceph_image}|g" %{buildroot}%{_datadir}/k8s-yaml/rook/ceph/cluster*
sed -i -e "s|image: .*|image: %{rook_image}|g" %{buildroot}%{_datadir}/k8s-yaml/rook/ceph/toolbox*
sed -i -e "s|/usr/local/bin/toolbox.sh|%{_bindir}/toolbox.sh|g" %{buildroot}%{_datadir}/k8s-yaml/rook/ceph/toolbox*

# Install the helm charts
mkdir -p %{buildroot}%{_datadir}/%{name}-ceph-helm-charts/operator
cp -pr cluster/charts/rook-ceph/* %{buildroot}%{_datadir}/%{name}-ceph-helm-charts/operator
sed -i -e "s|\".*/cephcsi/cephcsi:.*|\"%{ceph_csi_image}\"|g" %{buildroot}%{_datadir}/%{name}-ceph-helm-charts/operator/values.yaml

# For the integration test tooling, store files with the current Rook and Ceph image names
# These files can be cat'ed to get these without needing to do special processing
%define rook_integration_dir %{buildroot}%{_datadir}/rook-integration
mkdir -p %{rook_integration_dir}
echo -n %{rook_image}     > %{rook_integration_dir}/rook-image-name
echo -n %{ceph_image}     > %{rook_integration_dir}/ceph-image-name
echo -n %{ceph_csi_image} > %{rook_integration_dir}/ceph-csi-image-name
for f in %{rook_integration_dir}/*; do cat "$f"; done

################################################################################
# Specify which files we built belong to each package
################################################################################
# rook-version-build.arch.rpm
%files
%defattr(-,root,root,-)
%{_bindir}/rook
%{_bindir}/toolbox.sh

# rook-rookflex-version-build.arch.rpm
%files rookflex
%{_bindir}/rookflex

# rook-k8s-yaml-version-build.arch.rpm
%files k8s-yaml
%dir %{_datarootdir}/k8s-yaml
%dir %{_datarootdir}/k8s-yaml/rook
%dir %{_datarootdir}/k8s-yaml/rook/ceph
%{_datadir}/k8s-yaml/rook/ceph/

%files ceph-helm-charts
%doc %{_datadir}/%{name}-ceph-helm-charts/operator/README.md
%{_datadir}/%{name}-ceph-helm-charts

# rook-integration-version-build.arch.rpm
%files integration
# integration test binary
%{_bindir}/rook-integration
# integration test helper files
%dir %{_datarootdir}/rook-integration
%{_datadir}/rook-integration

################################################################################
# Finalize
################################################################################

# Rook RPMs aren't for users to install, just to be put in containers, so don't
# bother adding docs or changelog or anything

%changelog
* Tue Mar 31 2020 Kristoffer Gronlund <kgronlund@suse.com>
- Update to v1.2.7 (bsc#1168160):
  * Apply the expected lower PG count for rgw metadata pools (#5091)
  * Reject devices smaller than 5GiB for OSDs (#5089)
  * Add extra check for filesystem to skip boot volumes for OSD configuration (#5022)
  * Avoid duplication of mon pod anti-affinity (#4998)
  * Update service monitor definition during upgrade (#5078)
  * Resizer container fix due to misinterpretation of the cephcsi version (#5073-1)
  * Set ResourceVersion for Prometheus rules (#4528)
  * Upgrade doc clarification for RBAC related to the helm chart (#5054)
* Wed Mar 18 2020 Kristoffer Gronlund <kgronlund@suse.com>
- Update to v1.2.6:
  * Update default Ceph version to v14.2.8 (#4960)
  * Fix for OSDs on PVCs that were crashing on Ceph v14.2.8 (#4960)
  * Mount /udev so the osds can discover device info (#5001)
  * Query for the topology.kubernetes.io labels in K8s 1.17 or newer for the CRUSH hierarchy (#4989)
  * Log a warning when useAllNodes is true, but nodes are defined in the cluster CR ([commit](https://github.com/rook/rook/pull/4974/commits/69c9ed4206f47644687733396d87022e93d312a3))
* Tue Mar 10 2020 Kristoffer Gronlund <kgronlund@suse.com>
- ceph: orchestrator cli name change
  * Add orchestrator-cli-rename.patch
* Thu Feb 20 2020 Kristoffer Gronlund <kgronlund@suse.com>
- ceph: populate CSI configmap for external cluster
* Tue Feb 18 2020 Kristoffer Gronlund <kgronlund@suse.com>
- Update to v1.2.4:
  * Stop garbage collector from deleting the CSI driver unexpectedly (#4820)
  * Upgrade legacy OSDs created with partitions created by Rook (#4799)
  * Ability to set the pool target_size_ratio (#4803)
  * Improve detection of drain-canaries and log significant nodedrain scheduling events (#4679)
  * Sort flexvolume docs and update for kubespray (#4747)
  * Add OpenShift common issues documentation (#4764)
  * Improved integration test when cleaning devices (#4796)
* Mon Jan 27 2020 Kristoffer Gronlund <kgronlund@suse.com>
- Package helm charts for the rook operator for ceph (SES-799)
* Mon Jan 27 2020 Kristoffer Gronlund <kgronlund@suse.com>
- Update to v1.2.2:
  * Allow multiple clusters to set useAllDevices (#4692)
  * Operator start all mons before checking quorum if they are all down (#4531)
  * Ability to disable the crash controller (#4533)
  * Document monitoring options for the cluster CR (#4698)
  * Apply node topology labels to PV-backed OSDs in upgrade from v1.1 (#4616)
  * Update examples to Ceph version v14.2.6 (#4653)
  * Allow integration tests in minimal config to run on multiple K8s versions (#4674)
  * Wrong pod name and hostname shown in alert CephMonHighNumberOfLeaderChanges (#4665)
  * Set hostname properly in the CRUSH map for non-portable OSDs on PVCs (#4658)
  * Update OpenShift example manifest to watch all namespaces for clusters (#4668)
  * Use min_size defaults set by Ceph instead of overriding with Rook's defaults (#4638)
  * CSI driver handling of upgrade from OCP 4.2 to OCP 4.3 (#4650-1)
  * Add support for the k8s 1.17 failure domain labels (#4626)
  * Add option to the cluster CR to continue upgrade even with unclean PGs (#4617)
  * Add K8s 1.11 back to the integration tests as the minimum version (#4673)
  * Fixed replication factor flag and the master addresses (#4625)
* Wed Jan  8 2020 Kristoffer Gronlund <kgronlund@suse.com>
- Update to v1.2.1:
  * Add missing env var  `ROOK_CEPH_MON_HOST` for OSDs (#4589)
  * Avoid logging sensitive info when debug logging is enabled (#4568)
  * Add missing vol mount for encrypted osds (#4583)
  * Bumping ceph-operator memory limit to 256Mi (#4561)
  * Fix object bucket provisioner when rgw not on port 80 (#4508)
* Fri Dec 20 2019 Kristoffer Gronlund <kgronlund@suse.com>
- Update to v1.2.0:
  * Security audit completed by Trail of Bits found no major concerns
  * Ceph: Added a new "crash collector" daemon to send crash telemetry
    to the Ceph dashboard, support for priority classes, and a new
    CephClient resource to create user credentials
  * The minimum version of Kubernetes supported by Rook changed from
    1.11 to 1.12.
  * Device filtering is now configurable for the user by adding an
    environment variable
    + A new environment variable DISCOVER_DAEMON_UDEV_BLACKLIST is
    added through which the user can blacklist the devices
    + If no device is specified, the default values will be used to
    blacklist the devices
  * The topology setting has been removed from the CephCluster CR. To
    configure the OSD topology, node labels must be applied.
  * See the OSD topology topic. This setting only affects OSDs when
    they are first created, thus OSDs will not be impacted during
    upgrade.
  * The topology settings only apply to bluestore OSDs on raw devices.
    The topology labels are not applied to directory-based OSDs.
  * Creation of new Filestore OSDs on disks is now deprecated.
    Filestore is in sustaining mode in Ceph.
    + The storeType storage config setting is now ignored
    + New OSDs created in directories are always Filestore type
    + New OSDs created on disks are always Bluestore type
    + Preexisting disks provisioned as Filestore OSDs will remain as
    Filestore OSDs
  * Rook will no longer automatically remove OSDs if nodes are removed
    from the cluster CR to avoid the risk of destroying OSDs
    unintentionally. To remove OSDs manually, see the new doc on OSD
    Management
- Update csi-dummy-images.patch
- Update flexvolume-dir.patch
- Drop outdated patch 0001-bsc-1152690-ceph-csi-Driver-will-fail-with-error.patch
* Tue Dec  3 2019 Kristoffer Gronlund <kgronlund@suse.com>
- Update rook to v1.1.7:
  * Skip osd prepare job creation if osd daemon exists for the pvc (#4277)
  * Stop osd process more quickly during pod shutdown to reduce IO unresponsiveness (#4328)
  * Add osd anti-affinity to the example of OSDs on PVCs (#4326)
  * Properly set app name on the cmdreporter (#4323)
  * Ensure disruption draining state is set and checked correctly (#4319)
  * Update LVM filter for OSDs on PVCs (#4312)
  * Fix topology logic for disruption drains (#4221)
  * Skip restorecon during ceph-volume configuration (#4260)
  * Added a note around snapshot CRD cleanup (#4302)
  * Storage utilization alert threshold and timing updated (#4286)
  * Silence disruption errors if necessary and add missing errors (#4288)
  * Create csi keys and secrets for external cluster (#4276)
  * Add retry to ObjectUser creation (#4149)
* Wed Nov  6 2019 Kristoffer Gronlund <kgronlund@suse.com>
- Update rook to v1.1.6:
  * Flex driver should not allow attach before detach on a different node (#3582)
  * Properly set the ceph-mgr annotations (#4195)
  * Only trigger an orchestration if the cluster CR changed (#4252)
  * Fix setting rbdGrpcMetricsPort in the helm chart (#4202)
  * Document all helm chart settings (#4202)
  * Support all layers of CRUSH map with node labels (#4236)
  * Skip orchestration restart on device config map update for osd on pvc (#4124)
  * Deduplicate tolerations collected for the drain canary pods (#4220)
  * Role bindings are missing for pod security policies (#3851)
  * Continue with orchestration if a single mon pod fails to start (#4146)
  * OSDs cannot call 'restorecon' when selinux is enabled (#4214)
  * Use the rook image for drain canary pods (#4213)
  * Allow setting of osd prepare resource limits (#4182)
  * Documentation for object bucket provisioning (#3882)
* Tue Nov  5 2019 Kristoffer Gronlund <kgronlund@suse.com>
- Update rook to v1.1.4:
  * OSD config overrides were ignored for some upgraded OSDs (#4161)
  * Enable restoring a cluster after disaster recovery (#4021)
  * Enable upgrade of OSDs configured on PVCs (#3996)
  * Automatically removing OSDs requires setting: removeOSDsIfOutAndSafeToRemove(#4116)
  * Rework csi keys and secrets to use minimal privileges (#4086)
  * Expose OSD prepare pod resource limits (#4083)
  * Minimum K8s version for running OSDs on PVCs is 1.13 (#4009)
  * Add 'rgw.buckets.non-ec' to list of RGW metadataPools (#4087)
  * Hide wrong error for clusterdisruption controller (#4094)
  * Multiple integration test fixes to improve CI stability (#4098)
  * Detect mount fstype more accurately in the flex driver (#4109)
  * Do not override mgr annotations (#4110)
  * Add OSDs to proper buckets in crush hierarchy with topology awareness (#4099)
  * More robust removal of cluster finalizer (#4090)
  * Take activeStandby into account for the CephFileSystem disruption budget (#4075)
  * Update the CSI CephFS registration directory name (#4070)
  * Fix incorrect Ceph CSI doc links (#4081)
  * Remove decimal places for osdMemoryTargetValue monitoring setting (#4046)
  * Relax pre-requisites for external cluster to allow connections to Luminous (#4025)
  * Avoid nodes getting stuck in OrchestrationStatusStarting during OSD config (#3817)
  * Make metrics and liveness port configurable (#4005)
  * Correct system namespace for CSI driver settings during upgrade (#4040)
- Update csi-dummy-images.patch
- Update csi-template-paths.patch
- Update 0001-bsc-1152690-ceph-csi-Driver-will-fail-with-error.patch
* Wed Oct  2 2019 Kristoffer Gronlund <kgronlund@suse.com>
- Force use of ceph kernel client driver (bsc#1152690)
- Add 0001-bsc-1152690-ceph-csi-Driver-will-fail-with-error.patch
* Tue Oct  1 2019 Blaine Gardner <blaine.gardner@suse.com>
- Define build shell as /bin/bash for usage of `=~` conditional (bsc#1152559)
* Mon Sep 30 2019 Blaine Gardner <blaine.gardner@suse.com>
- Fix csi-dummy-images.patch to work with Go linker's -X flag (bsc#1152559)
  + update linker flags themselves to remove comments from flags
  + add test to spec file to verify linker flags are working in future
* Thu Sep 26 2019 Blaine Gardner <blaine.gardner@suse.com>
- Fix 2 improper RPM spec variable references in specfile (bsc#1151909)
* Wed Sep 25 2019 Blaine Gardner <blaine.gardner@suse.com>
- Use lightweight git tags when determining Rook version from source in tarball script (bsc#1151909)
  + Build should now be tagged appropriately as version 1.1.1.0 instead of 1.1.0.x
- Override some Rook defaults with linker flags at build time:
  + CSI image -> SUSE image
  + FlexVolume dir (for Kubic)
- Add patches for:
  + updating CSI image to a dummy value later changed at linker time
  + updating CSI template paths to the ones installed by rook-k8s-manifests
  + update the FlexVolume dir path to be compatible with Kubic
- Remove previously applied SUSE-specific changes that are now taken care of by the above patches
- Add patch: csi-dummy-images.patch
- Add patch: csi-template-paths.patch
- Add patch: flexvolume-dir.patch
* Wed Sep 25 2019 Kristoffer Gronlund <kgronlund@suse.com>
- rook-k8s-yaml: Fix YAML indentation of cephcsi image value (bsc#1152008)
* Wed Sep 25 2019 Blaine Gardner <blaine.gardner@suse.com>
- Update Rook to match upstream version v1.1.1 (bsc#1151909)
  + Disable the flex driver by default in new clusters
  + MDB controller to use namespace for checking ceph status
  + CSI liveness container socket file
  + Add list of unusable directories paths
  + Remove helm incompatible chars from values.yaml
  + Fail NFS-ganesha if CephFS is not configured
  + Make lifecycle hook chown less verbose for OSDs
  + Configure LVM settings for rhel8 base image
  + Make kubelet path configurable in operator for csi (#392
  + OSD pods should always use hostname for node selector
  + Deactivate device from lvm when OSD pods are shutting down
  + Add CephNFS to OLM's CSV
  + Tolerations for drain detection canaries
  + Enable ceph-volume debug logs
  + Add documentation for CSI upgrades from v1.0 (#386
  + Add a new skipUpgradeChecks property to allow forcing upgrades
  + Include CSI image in helm chart values (#385
  + Use HTTP port if SSL is disabled
  + Enable SSL for dashboard by default
  + Enable msgr2 properly during upgrades
  + Nautilus v14.2.4 is the default Ceph image
  + Ensure the ceph-csi secret exists on upgrade
  + Disable the min PG warning if the pg_autoscaler is enabled
  + Disable the warning for bluestore warn on legacy statfs
- add SUSE-specific changes to manifests:
  + uncomment ROOK_CSI_CEPH_IMAGE var
  + set FlexVolume dir path for Kubic
  + add ROOK_CSI_*_TEMPLATE_PATH configs
* Mon Sep 16 2019 Kristoffer Gronlund <kgronlund@suse.com>
- rook-k8s-yaml: Revert to buildrequire for ceph (bsc#1151479)
* Fri Sep 13 2019 Blaine Gardner <blaine.gardner@suse.com>
- Update tar creation script
  + build rook tag 'v1.1.0' from 'suse-release-1.1' branch
- Update Rook to tag 'v1.1.0' (bsc#1151479)
  + fix HighMonLeaderChanges alert
  + add leases rules to CSI rules
  + only schedule node drain canaries on nodes with OSDs
  + increase sidecar timeout from 60s to 150s
  + use combined (stdout+stderr) output from ceph-volume
  + set command property for the OSD prepare init container blkdevmapper
  + change OSD DOWN message to debug level
  + discovery daemon: ignore updates on nbd devices
* Mon Sep  9 2019 Blaine Gardner <blaine.gardner@suse.com>
- Support upstream beta tags by replacing hyphens in release tag with tildes
  + RPMs sorts tildes before anything else to support vX.Y.0~beta.B coming before vX.Y.0
* Mon Sep  9 2019 Blaine Gardner <blaine.gardner@suse.com>
- Update tar creation script
  + fail on more types of script errors
  + exit properly on error
  + allow checking out tags
  + allow parsing tag versions with hyphens (e.g., v1.1.0-beta.1)
  + use revision (tag) 'v1.1.0-beta.1' from ('suse-release-1.1' branch)
- Update Rook to tag 'v1.1.0-beta.1'
  + support external Ceph clusters
  + fix osdsPerDevice config
  + add portable failure-domain label to OSD deployments
  + add bucket provisioner
  + use deployment with leader election instead of stateful set for CSI drivers
  + fix alerting & recording rules
  + fix race in create ObjectUser
  + support mon migrations without rebuilds when using PVCs
  + allow CRUSH map to be based on PVCs for PVC-based OSDs
  + fix md and dev ordering for ceph-volume batch operations
  + improve upgrades when a mon is down
  + fix service account name for CSI RBD provisioner
  + add -pidlimit flag for CephFS and RBD plugins for CSI driver
  + add image pull secrets option to manifests
  + remove OSD pods marked out if pod is more than an hour old
  + add --db-devices flag to ceph-volume provisioning & fix MB size bug
  + implement GRPC metrics for cephcsi
  + clean up verbose Ceph logging
  + update upgrade documentation for v1.1 release
  + remove unused attacher service account
  + add dynamic expansion to FlexVolume driver
  + fix random OSD pod failures when using PVCs
  + fix osd prepare panic
  + lower minimum OSD memory to 2GB
  + add ability to enable mgr modules via CRD (notably the pg_autoscaler module)
  + fix topologyAware on PVC-based OSDs
  + add support for OpenShift machine disruption budgets
* Fri Aug 23 2019 Kristoffer Gronlund <kgronlund@suse.com>
- Make rook-k8s-yaml require the matching ceph version
- Update rook to commit 692553221d8b18fec8aa3ccdc5872e51f05ca372:
  +  uncomment ROOK_CSI_CEPH_IMAGE var
* Fri Aug 16 2019 Jan Engelhardt <jengelh@inai.de>
- Trim redundant wording from description.
* Tue Aug 13 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Tech preview release for containers (bsc#1145433)
* Mon Aug 12 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Update Rook to commit e9abbf4831673a9a5545971532ae326e95f3ea60
  + enable the ceph-csi driver by default
  + remove csi default settings from yaml
  + add option to disable flex driver
  + allow the discovery daemon to be optional
  + automatically create the csi secret with the cluster
  + Allow to launch pods when memory request is set (but no memory limit)
  + ceph: chown with init container
  + ceph: when mons use pvc mount volume at subpath
- csi was merged to operator.yaml, sed to correct file
* Fri Aug  2 2019 Blaine Gardner <blaine.gardner@suse.com>
- Fix build broken with creation of new rook-integration helper files
- Put helper files into /usr/share/rook-integration dir
- Change name of 'integration' binary to 'rook-integration'
* Thu Aug  1 2019 Blaine Gardner <blaine.gardner@suse.com>
- Generate files which contain the names of all images used in the manifests produced by this build
  which are installed with the rook-integration package to assist the integration tooling.
* Thu Aug  1 2019 Blaine Gardner <blaine.gardner@suse.com>
- Update spec file to build rook-integration binary
  - Building test binaries is different from building main binaries, so manual steps needed
- Apply linker flags to rookflex binary also (just in case)
- Slightly rework rook-k8s-yaml summary description
* Fri Jul 26 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Correct toolbox location in manifest files
* Tue Jul 23 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Update Rook to commit 7a48482f5cd92397eef068d097ad233739ceae06
  + ceph: run ceph processes with the 'ceph' user
  + Correct typo about skipVolumeForDirectory's code comment
  + Fix: topologyAware does not pick up failure domains.
  + Correct typo about skipVolumeForDirectory's code comment
* Mon Jul 22 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Update Rook to commit 0141cfea50a7f80ff1ee67aa8cc7ad28edc79a64
  + OSD startup on SDN for error "Cannot assign requested address"
  + Change default frontend on nautilus to beast
  + RGW daemon updates:
    ~ Remove support for AllNodes where we would deploy one rgw per node on all the nodes
    ~ Each rgw deployed has its own cephx key
    ~ Upgrades will automatically transition these changes to the rgw daemons
  + Correct --ms-learn-addr-from-peer=false argument for ceph-osd
  + When updating the CephCluster CR to run unsupported octopus, fix operator panic
  + Add metrics for the flexvolume driver
  + Set the fully qualified apiVersion on the OwnerReferences for cleanup on OpenShift
  + Stop enforcing crush tunables for octopus warning
  + Apply the osd nautilus flag for upgrade
  + RGW: Set proper port syntax for beast in nautilus deployments
  + Stop creating initial crushmap to avoid incorrect crush map warning
  + Use correct rounding of PV size for binding of PVCs (for example G or Gi)
- Add psp to common.yaml
* Wed Jul 17 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Use ceph-base pattern instead of packages
* Fri Jul 12 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Fix sed expression to replace correct link
* Fri Jul 12 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Add ceph-csi as a dependency and update manifest link with it
* Thu Jul 11 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- correct version for Rook build that doesn's support "+"
* Tue Jul  9 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- noarch for the rook-k8s-yaml package
- update rook to a265cdf commit
  + added ROOK_CSI_* template pathes
- modify update script for none Go enviroment
* Mon Jul  8 2019 Blaine Gardner <blaine.gardner@suse.com>
- Fix subtly broken dependency (vendor dir) generation
- Generate two tarballs for builds to follow latest upstream best practices for Golang RPM builds
  + primary source tarball is unmodified from source code, and vendor dir is a separate tarball
- Add Rook toolbox script to main rook package
- Update manifests to use SUSE image for toolbox
- Update spec file dependencies
  + remove old Rook dependencies
  + add missing dependencies from the upstream Ceph image (notably nfs-ganesha and CSI requirements)
- Update build to include go build linker flag to set rook binary's internal version representation
- Remove FlexVolume config from manifests, as we intend to use CSI henceforth
- Update Rook to commit c4a3763b6415a118aedaee52eaf76cbdf6b0dabb
  + delay starting Rook system daemons until a CephCluster is created
  + stop setting CRUSH tunable automatically
  + use --ms-learn-addr-from-peer flag for OSDs for Ceph v14.2.2 and up - https://github.com/rook/rook/issues/3140
  + when appropriate, look for rook and tini binaries in PATH if not found in default location
  + set fully qualified apiVersion on OwnerReferences
  + OSDs marked out by Ceph will have their Kubernetes resources automatically cleaned up (will not be removed from CRUSH map)
  + add NodeAffinity to system daemons
* Wed Jul  3 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- restore package name and correct unique containers tags
* Tue Jun 18 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- changing package name as it couldn't comply to the container tag name
  + https://github.com/containers/image/issues/649
* Tue Jun 18 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Ceph added as a requirement to get it version for the container image
- Added service to strip Ceph version from ceph package
- Fixed sed for the container images names
* Tue Jun 18 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Update Rook to commit ad89e4f47e744c484b8e264e351f6276a42eedfc
  + change csi template path to match rook-k8s-yaml package files
- Fix update-tarball.sh to delete right files
- Add all manifests to the rook-k8s-yaml packages
- Fix rook binary location from /usr/local/bin/ to /usr/bin/
* Tue Jun 18 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Fix update-tarball.sh to ignore errors where is needed
- Update spec to include additional ceph-csi config files
* Mon Jun 17 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Adding additional files as Source to spec
* Mon Jun 17 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Update tarball generation script to get correct version
- Correct tarball name, spec version and package name
- Add new k8s-yaml package to distribute manifests files
* Tue May 21 2019 Denis Kondratenko <denis.kondratenko@suse.com>
- Update rook to commit 700cdd36fe9107733a717fac934c2bedd91fd290
- build from https://github.com/SUSE/rook/tree/suse-master
- based on Rook v1.0.0
- Ceph:
  + Ceph Nautilus (v14) is now supported by Rook
  + The Ceph-CSI driver is available for experimental mode
  + A CephNFS CRD will start NFS daemon(s) for exporting CephFS volumes or RGW buckets
  + The number of mons can be increased automatically when new nodes come online
  + OSDs provisioned by ceph-volume now supports metadataDevice and databaseSizeMB options
* Mon Apr 29 2019 Jan Fajerski <jan.fajerski@suse.com>
- Update rook to commit c43b57844e37a7909beb362d08ef85fffdd5fed4
- build from https://github.com/SUSE/rook/tree/suse-master
- Ceph:
  + Improve rbd hotplug selection
  + set default version to nautilus
  + improved OSD removal
  + clean shutdown of CephFS
  + improve logging
  + improved upgrade ochestration
* Mon Apr  8 2019 Jan Fajerski <jan.fajerski@suse.com>
- Update rook to commit 69936c170cb3913a539eacf963993e9bb3545e8a
- Cassandra: Fix the mount point for th
- Ceph:
  + Improve mon failover cleanup and operator restart during failover
  + Enable host ipc for osd encryption
  + Add missing "host path requires privileged" setting to the helm chart
* Tue Jan 29 2019 Jan Fajerski <jan.fajerski@suse.com>
- Update rook to commit 8e263cd9c31b0a310b0d1180e58ac843b432b14b
- Correctly capture and log the stderr output from child processes
- Allow disabling setting fsgroup when mounting a volume
- Allow configuration of SELinux relabeling
- Correctly set the secretKey used for cephfs mounts
- Set ceph-mgr privileges to prevent the dashboard from failing on rbd mirroring settings
- Correctly configure the ssl certificate for the RGW service
- Allow configuration of the dashboard port
- Allow disabling of ssl on the dashboard
* Thu Jan 17 2019 Jan Fajerski <jan.fajerski@suse.com>
- Update rook to commit d0cd8cec72176bf28a3ac0ba1457297151004f79
- Ceph CRDs have been declared stable V1.
- Ceph versioning is decoupled from the Rook version. Luminous and Mimic can be run in production, or Nautilus in experimental mode.
- Ceph upgrades are greatly simplified
- The minimum version of Kubernetes supported by Rook changed from 1.7 to 1.8
* Mon Jan 14 2019 Jan Fajerski <jan.fajerski@suse.com>
- install to /usr/local/bin as rook hardcodes this path for rookflex
* Tue Oct 30 2018 Jan Fajerski <jan.fajerski@suse.com>
- Update rook to commit bf2759e317c44c0ad0aaf635e04cbd72a002a5a0
- Refactor ceph containers to disconnect rook and ceph versions
* Thu Apr 26 2018 blaine.gardner@suse.com
- Update Rook build to use '-buildmode=pie' flag
- Version at commit e11b3d863728667ea018aa329f3ad907360473cf
* Tue Apr 24 2018 blaine.gardner@suse.com
- Initial submission
- Version at commit 71514921ad8e41ede6f2814e7004f0465e3dd0f7
- Modifications to upstream Rook to support SLE:
  - None
